==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Your_Account/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/





define("_EMAIL","Email");          //
define("_YES","");
define("_NO","ͳ");

define("_OPTIONAL","(')");
define("_REQUIRED","(')");
define("_SAVECHANGES"," ");
define("_THRESHOLD","³  ");
define("_NOCOMMENTS"," ");
define("_NESTED"," ");
define("_FLAT"," ");
define("_THREAD","  ");
define("_OLDEST","  ");
define("_NEWEST","  ");
define("_HIGHEST","  ");


define("_ERRORINVEMAIL",":  Email");
define("_ERROREMAILSPACES",":  Email    ");
define("_ERRORINVNICK",":  '");
define("_NICK2LONG","'   ( 25 )");
define("_NAMERESERVED",":  '  ");
define("_NICKNOSPACES",":      .");
define("_NICKTAKEN",":  '  .");
define("_EMAILREGISTERED",":  Email   ");
define("_UUSERNAME","' ");
define("_FINISH","");
define("_YOUUSEDEMAIL",",   ,   email ");
define("_TOREGISTER","  ");
define("_FOLLOWINGMEM"," c :");
define("_UNICKNAME","':");
define("_UPASSWORD",":");
define("_USERPASS4"," ");
define("_YOUAREREGISTERED","  .     email   .");
define("_THISISYOURPAGE"," -   ");
define("_AVATAR","");
define("_WEBSITE"," ");
define("_ICQ"," ICQ");
define("_AIM"," AIM");
define("_YIM"," YIM");
define("_MSNM"," MSNM");
define("_LOCATION","");
define("_OCCUPATION","г ");
define("_INTERESTS","");
define("_SIGNATURE","ϳ");
define("_MYHOMEPAGE","  :");
define("_MYEMAIL","̳ Email:");
define("_EXTRAINFO"," ");
define("_NOINFOFOR","     ");
define("_LAST10COMMENTS"," 10 ");
define("_LAST10SUBMISSIONS"," 10  ");
define("_LOGININCOR"," !  ...");
define("_USERLOGIN"," ");
define("_USERREGLOGIN"," ");
define("_REGNEWUSER","");
define("_LIST","");
define("_NEWUSER","");
define("_PASSWILLSEND","(    email )");
define("_COOKIEWARNING",":    kie.");
define("_ASREGUSER","    :");
define("_ASREG1","    ");
define("_ASREG2","      ");
define("_ASREG3","      ");
define("_ASREG4",",        ");
define("_ASREG5"," ");
define("_ASREG6","   ");
define("_ASREG7","    ...");
define("_REGISTERNOW"," !  !");
define("_WEDONTGIVE","      .");
define("_ALLOWEMAILVIEW","     email");
define("_OPTION","");
define("_PASSWORDLOST"," ?");
define("_NOPROBLEM","³     :<br> 1.   '    .  email       .<br> 2.    '      .      .");
define("_CONFIRMATIONCODE"," ");
define("_SENDPASSWORD","³ ");
define("_YOUARELOGGEDOUT","  !");
define("_SORRYNOUSERINFO",",      ");
define("_USERACCOUNT"," ");
define("_AT","");
define("_HASTHISEMAIL","  email.");
define("_AWEBUSERFROM"," ");
define("_HASREQUESTED","    .");
define("_YOURNEWPASSWORD","   :");
define("_YOUCANCHANGE","      ");
define("_IFYOUDIDNOTASK","      -         ,         -   .");
define("_UPDATEFAILED","  .   .");
define("_PASSWORD4"," ");
define("_MAILED","  Email.");
define("_CODEREQUESTED","      .");
define("_YOURCODEIS","  :");
define("_WITHTHISCODE","       ");
define("_IFYOUDIDNOTASK2","      -         .");
define("_CODEFOR","  ");
define("_USERPASSWORD4","  ");
define("_UREALNAME"," '");
define("_UREALEMAIL"," Email");
define("_EMAILNOTPUBLIC"," Email   . ³        '   .");
define("_UFAKEMAIL"," Email");
define("_EMAILPUBLIC","( Email ,     )");
define("_YOURHOMEPAGE","  ");
define("_YOURAVATAR"," ");
define("_YICQ"," ICQ");
define("_YAIM"," AIM");
define("_YYIM"," YIM");
define("_YMSNM"," MSNM");
define("_YLOCATION","̳");
define("_YOCCUPATION","г ");
define("_YINTERESTS","");
define("_255CHARMAX","( 255 .  ,   HTML-)");
define("_CANKNOWABOUT","( 255 . ,      )");
define("_TYPENEWPASSWORD","(      )");
define("_SOMETHINGWRONG"," ...   ?");
define("_PASSDIFFERENT","   .");
define("_CHARLONG","");
define("_AVAILABLEAVATARS","  ");
define("_NEWSINHOME","ʳ    ");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","  ");
define("_CHECKTHISOPTION","(      '    -     )");
define("_YOUCANUSEHTML","(   HTML-, , ,     )");
define("_SELECTTHEME"," ");
define("_THEMETEXT1","      .");
define("_THEMETEXT2","     .");
define("_THEMETEXT3","(       )");
define("_DISPLAYMODE"," : ");
define("_SORTORDER"," : ");
define("_COMMENTSWILLIGNORED","<br>(     )");
define("_UNCUT"," ");
define("_EVERYTHING"," ");
define("_FILTERMOSTANON","Գ  ");
define("_USCORE","");
define("_SCORENOTE","    0,    -  1.     .");
define("_NOSCORES","  ");
define("_HIDDESCORES","<br>( :  ,     )");
define("_MAXCOMMENT","  ");
define("_TRUNCATES","<br>(      \" \")");
define("_BYTESNOTE"," (1024  = 1K)");
define("_USENDPRIVATEMSG","³  ");
define("_THEMESELECTION"," ");
define("_COMMENTSCONFIG"," ");
define("_HOMECONFIG","  ");
define("_PERSONALINFO"," ");
define("_USERSTATUS","  ");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","  ");
define("_CONFIGCOMMENTS"," ");
define("_CHANGEHOME","  ");
define("_LOGOUTEXIT"," /");
define("_SELECTTHETHEME"," ");
define("_PRIVATEMESSAGES","  ");
define("_EDITUSER"," ");
define("_RECEIVENEWSLETTER","Receive Newsletter by Email?");
define("_NOTSUBSCRIBED","You're not subscribed to our Newsletter");
define("_SUBSCRIBED","You're subscribed to our Newsletter");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");

?>

==> phpnuke-6.0.tgz: www/phpnuke/html/modules/Your_Account/language/lang-ukrainian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL","Email");
define("_YES","");
define("_NO","ͳ");
define("_OPTIONAL","(')");
define("_REQUIRED","(')");
define("_SAVECHANGES"," ");
define("_THRESHOLD","³  ");
define("_NOCOMMENTS"," ");
define("_NESTED"," ");
define("_FLAT"," ");
define("_THREAD","  ");
define("_OLDEST","  ");
define("_NEWEST","  ");
define("_HIGHEST","  ");
define("_ERRORINVEMAIL",":  Email");
define("_ERROREMAILSPACES",":  Email    ");
define("_ERRORINVNICK",":  '");
define("_NICK2LONG","'   ( 25 )");
define("_NAMERESERVED",":  '  ");
define("_NICKNOSPACES",":      .");
define("_NICKTAKEN",":  '  .");
define("_EMAILREGISTERED",":  Email   ");
define("_UUSERNAME","' ");
define("_FINISH","");
define("_YOUUSEDEMAIL",",   ,   email ");
define("_TOREGISTER","  ");
define("_FOLLOWINGMEM"," c :");
define("_UNICKNAME","':");
define("_UPASSWORD",":");
define("_USERPASS4"," ");
define("_YOUAREREGISTERED","  .     email   .");
define("_THISISYOURPAGE"," -   ");
define("_AVATAR","");
define("_WEBSITE"," ");
define("_ICQ"," ICQ");
define("_AIM"," AIM");
define("_YIM"," YIM");
define("_MSNM"," MSNM");
define("_LOCATION","");
define("_OCCUPATION","г ");
define("_INTERESTS","");
define("_SIGNATURE","ϳ");
define("_MYHOMEPAGE","  :");
define("_MYEMAIL","̳ Email:");
define("_EXTRAINFO"," ");
define("_NOINFOFOR","     ");
define("_LAST10COMMENTS"," 10 ");
define("_LAST10SUBMISSIONS"," 10  ");
define("_LOGININCOR"," !  ...");
define("_USERLOGIN"," ");
define("_USERREGLOGIN"," ");
define("_REGNEWUSER","");
define("_LIST","");
define("_NEWUSER","");
define("_PASSWILLSEND","(    email )");
define("_COOKIEWARNING",":    kie.");
define("_ASREGUSER","    :");
define("_ASREG1","    ");
define("_ASREG2","      ");
define("_ASREG3","      ");
define("_ASREG4",",        ");
define("_ASREG5"," ");
define("_ASREG6","   ");
define("_ASREG7","    ...");
define("_REGISTERNOW"," !  !");
define("_WEDONTGIVE","      .");
define("_ALLOWEMAILVIEW","     email");
define("_OPTION","");
define("_PASSWORDLOST"," ?");
define("_NOPROBLEM","³     :<br> 1.   '    .  email       .<br> 2.    '      .      .");
define("_CONFIRMATIONCODE"," ");
define("_SENDPASSWORD","³ ");
define("_YOUARELOGGEDOUT","  !");
define("_SORRYNOUSERINFO",",      ");
define("_USERACCOUNT"," ");
define("_AT","");
define("_HASTHISEMAIL","  email.");
define("_AWEBUSERFROM"," ");
define("_HASREQUESTED","    .");
define("_YOURNEWPASSWORD","   :");
define("_YOUCANCHANGE","      ");
define("_IFYOUDIDNOTASK","      -         ,         -   .");
define("_UPDATEFAILED","  .   .");
define("_PASSWORD4"," ");
define("_MAILED","  Email.");
define("_CODEREQUESTED","      .");
define("_YOURCODEIS","  :");
define("_WITHTHISCODE","       ");
define("_IFYOUDIDNOTASK2","      -         .");
define("_CODEFOR","  ");
define("_USERPASSWORD4","  ");
define("_UREALNAME"," '");
define("_UREALEMAIL"," Email");
define("_EMAILNOTPUBLIC"," Email   . ³        '   .");
define("_UFAKEMAIL"," Email");
define("_EMAILPUBLIC","( Email ,     )");
define("_YOURHOMEPAGE","  ");
define("_YOURAVATAR"," ");
define("_YICQ"," ICQ");
define("_YAIM"," AIM");
define("_YYIM"," YIM");
define("_YMSNM"," MSNM");
define("_YLOCATION","̳");
define("_YOCCUPATION","г ");
define("_YINTERESTS","");
define("_255CHARMAX","( 255 .  ,   HTML-)");
define("_CANKNOWABOUT","( 255 . ,      )");
define("_TYPENEWPASSWORD","(      )");
define("_SOMETHINGWRONG"," ...   ?");
define("_PASSDIFFERENT","   .");
define("_CHARLONG","");
define("_AVAILABLEAVATARS","  ");
define("_NEWSINHOME","ʳ    ");
define("_MAX127","(max. 127):");
define("_ACTIVATEPERSONAL","  ");
define("_CHECKTHISOPTION","(      '    -     )");
define("_YOUCANUSEHTML","(   HTML-, , ,     )");
define("_SELECTTHEME"," ");
define("_THEMETEXT1","      .");
define("_THEMETEXT2","     .");
define("_THEMETEXT3","(       )");
define("_DISPLAYMODE"," : ");
define("_SORTORDER"," : ");
define("_COMMENTSWILLIGNORED","<br>(     )");
define("_UNCUT"," ");
define("_EVERYTHING"," ");
define("_FILTERMOSTANON","Գ  ");
define("_USCORE","");
define("_SCORENOTE","    0,    -  1.     .");
define("_NOSCORES","  ");
define("_HIDDESCORES","<br>( :  ,     )");
define("_MAXCOMMENT","  ");
define("_TRUNCATES","<br>(      \" \")");
define("_BYTESNOTE"," (1024  = 1K)");
define("_USENDPRIVATEMSG","³  ");
define("_THEMESELECTION"," ");
define("_COMMENTSCONFIG"," ");
define("_HOMECONFIG","  ");
define("_PERSONALINFO"," ");
define("_USERSTATUS","  ");
define("_ONLINE","Online");
define("_OFFLINE","Offline");
define("_CHANGEYOURINFO","  ");
define("_CONFIGCOMMENTS"," ");
define("_CHANGEHOME","  ");
define("_LOGOUTEXIT"," /");
define("_SELECTTHETHEME"," ");
define("_PRIVATEMESSAGES","  ");
define("_EDITUSER"," ");
define("_RECEIVENEWSLETTER","Receive Newsletter by Email?");
define("_NOTSUBSCRIBED","You're not subscribed to our Newsletter");
define("_SUBSCRIBED","You're subscribed to our Newsletter");
define("_USERCHECKDATA","please check the following information. If all is correct you can proceed with the registration by clicking on \"Finish\" button, otherwise \"Go Back\" and change whatever information is needed.");
define("_USERFINALSTEP","New User Registration: Final Step");
define("_ACCOUNTCREATED","New User Account Created!");
define("_THANKSUSER","Thank you for registering at");
define("_YOUCANLOGIN","In a few seconds you'll receive an email from our system with your assigned password. Then you can login <a href=\"modules.php?name=Your_Account\">here</a>. Remember to change you password and to configure your account preferences. Hope you can enjoy our services.");
define("_BROWSEUSERS","Browse Users");
define("_SEARCHUSERS","Search Users");
define("_BROADCAST","Broadcast Public Message");
define("_BROADCASTTEXT","You can send a <i>Public Message</i> from here (255 characters max). This message will be displayed to all online users in the next 10 minutes. Any user online will see you message just once in a red bar under the site's logo. Any user can deactivate this feature from <a href=\"modules.php?name=Your_Account&amp;op=edithome\">here</a>. Please don't abuse. HTML code isn't allowed here.");
define("_SEND","Send");
define("_MESSAGEACTIVATE","Activate Broadcast Public Messages?");
define("_BROADCASTSENT","Your Broadcast Message has been sent.");
define("_BROADCASTNOTSENT","<b>ERROR:</b> Your Broadcast Message is empty or you already sent a message recently. To publish another message you need to wait about 10 minutes.");
define("_RETURNPAGE","Return to your personal page");
define("_MYHEADLINES","My Headlines");
define("_SELECTASITE","Select the site from which you want to read the headlines:");
define("_SELECTASITE2","Select a Web Site");
define("_ORTYPEURL","Or type the headlines RSS/XML url of your prefered site:");
define("_GO","Go");
define("_HEADLINESFROM","Headlines from");
define("_WEBMAIL", "WebMail");
define("_MESSAGES","Messages");
define("_RETURNACCOUNT", "Return to Your Account Page");
define("_ACCESSTO", "Access to");
define("_CREATEJOURNAL", "Create your own Journal");
define("_READHEADLINES", "Read custom headlines");
define("_POPMSGACTIVE","Activate Private Message PopUp?");
define("_READMYJOURNAL","Read My Journal");

?>
